import React, { useState, useEffect } from 'react';
import { Form, Icon, Input, Button, DatePicker, Select, Card, Row, Col, Pagination, Alert, Table, Avatar, Radio, Upload, message, notification } from 'antd';
import ImageUpload from '@/components/XForm/ImageUpload';
import moment from 'moment';
import request from '../../../utils/request';
import apis from '../../../services/apis';
import { router } from 'umi';

import Attribution from './components/attribution'
import BuildingSelect from '@/components/SelectButton/BuildSelect2';
import ConsultantSelect from '@/components/SelectButton/consultantSelect';
import ChannelSelect from '@/components/SelectButton/channelSelect';


const { TextArea } = Input;

const tailFormItemLayout = {
  labelCol: {
    xs: { span: 20 },
    sm: { span: 3 },
  },
  wrapperCol: {
    xs: { span: 20 },
    sm: { span: 16 },
  },
};

const openNotificationWithIcon = (type, message) => {
  notification[type]({
    message,
    description:
      '',
  });
}

function body(props) {
  const { getFieldDecorator } = props.form

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [visibleData, setVisibleData] = useState({ visible: false, customerId: '', realtyConsultant: '', buildingId: '' })

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [data, setData] = useState({})

  const { id } = props.location.query;

  if (id !== '') {
    // eslint-disable-next-line react-hooks/rules-of-hooks
    useEffect(() => {
      getById(id)
    }, [])
  }

  // 获取详情信息
  function getById(currentId) {
    request({ ...apis.customer.getDetail, urlData: { id: currentId } }).then(res => {
      // res.reportDate = moment(res.reportDate)
      if(res){
        let channelCustomer = {}
        if(res.channelCustomer){
          channelCustomer.channelId=res.channelCustomer.channelId
          channelCustomer.remark=res.channelCustomer.remark
          
        }
        if(res.customerVisit){
          channelCustomer.imageUrl=res.customerVisit.imageUrl
          // channelCustomer.remark=res.channelCustomer.remark
          
        }
        
        setData(res)
        props.form.setFieldsValue({...res,...channelCustomer})
      }
    
    })
  }

  function submitDate(data) {
    // props.form.setFieldsValue(res)
    console.log(data, 'data')
    const params ={
      auditResult:data.status,
      channelCustomerId:id,
      realtyConsultant:props.form.getFieldValue('realtyConsultant'),
      name:props.form.getFieldValue('name'),
      customerVisit:{ 
        imageUrl:props.form.getFieldValue('imageUrl'),
      },
      remark:props.form.getFieldValue('remark'),
    }
    // {
    //   "auditResult": "string",
    //   "channelCustomerId": "string",
    //   "customerVisit": {
    //     "buildingId": "string",
    //     "createDate": "2021-07-31T16:56:21.899Z",
    //     "customerId": "string",
    //     "customerVisitId": "string",
    //     "imageUrl": "string",
    //     "name": "string",
    //     "orgId": 0,
    //     "realtyConsultant": "string",
    //     "realtyConsultantName": "string",
    //     "recommendName": "string",
    //     "recommendPerson": "string",
    //     "remark": "string"
    //   },
    //   "realtyConsultant": "string"
    // }
    request({ ...apis.customer.auto, urlData: { id: id }, data: { ...params }}).then(() => {
      // eslint-disable-next-line no-unused-expressions
      openNotificationWithIcon('success', '操作成功')
      router.go(-1)
    }).catch(err => {
      // eslint-disable-next-line no-unused-expressions

    })
  }

  // 提交事件
  function handleSubmit(e) {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        submitDate({ status: '1' })
        // submitDate({ ...values })
      }
    });
  }





  return (
    <Card>
      <Form {...tailFormItemLayout} onSubmit={e => handleSubmit(e)} style={{ maxWidth: '1000px' }}>
        {/* <Form.Item label="客户ID" style={{ display: 'none' }}>
          {getFieldDecorator('channelCustomerId')(
            <Input
              placeholder="客户ID"
            />,
          )}
        </Form.Item>*/}
        <Form.Item label="项目ID" style={{ display: 'none' }}>
          {getFieldDecorator('buildingId')(
            <Input
              placeholder="项目ID"
            />,
          )}
        </Form.Item>
        <Form.Item label="意向项目：">
          {getFieldDecorator('buildingId')(
            <BuildingSelect
            disabled
              placeholder="意向项目"
              style={{width:'100%'}}
            />,
          )}
        </Form.Item> 
        <Form.Item label="客户姓名">
          {getFieldDecorator('name')(
            <Input placeholder="客户姓名" />,
          )}
        </Form.Item>
        <Form.Item label="归属渠道">
          {getFieldDecorator('channelId')(
            <ChannelSelect placeholder="归属渠道" disabled/>,
          )}
        </Form.Item>
        <Form.Item label="归属置业顾问">
          {getFieldDecorator('realtyConsultant')(
            <ConsultantSelect placeholder="归属置业顾问" buildingId={props.form.getFieldValue('buildingId')} />,
          )}
        </Form.Item>
        <Form.Item label="到访照片">
          {getFieldDecorator('imageUrl')(
            <ImageUpload />,
          )}
        </Form.Item>
        <Form.Item label="备注">
          {getFieldDecorator('remark')(
            <TextArea placeholder="客户描述" rows={10} />,
          )}
        </Form.Item>
       

        

        {/* <Form.Item label="归属置业顾问"
      >
          <Row gutter={8}>
            <Col span={12}>
              {getFieldDecorator('consultantName', {
                rules: [
                  {
                    required: true,
                    message: '请选择置业顾问',
                  },
                ],
              })(<Input placeholder="请选择置业顾问" />)}
            </Col>
            <Col span={12}>
              <Button onClick={() => showConsultant()}>选择</Button>
            </Col>
          </Row>
        </Form.Item> */}
        <Form.Item style={{ display: 'flex', justifyContent: 'center' }}>
          {data.status==='1'&&<><Button type="primary" htmlType="submit" >
            审核通过
          </Button>
          <Button type="danger" ghost style={{marginLeft: '4em'}} onClick={() => submitDate({ status: '2' })}>
            驳回
          </Button></>}
          <Button style={{marginLeft: '4em'}} onClick={() => router.goBack(-1)}>
            取消
          </Button>
        </Form.Item>
      </Form>

      {/* 选择置业顾问 */}
      {/* <Attribution visibleData={visibleData} onCancel={() => closeConsultant()} onSuccess={e => consultantSuccess(e)} /> */}
    </Card>
  );
}
const WrappedBody = Form.create({ name: 'body' })(body);

export default WrappedBody